@@ -12,7 +12,8 @@ import ast
 
 
 class LF_Input(InputData):
-    def __init__(self, input_data_path=None, process_name='LF', CommonDataObjct=None):
+    def __init__(self, input_data_path=None, process_data_path=None,
+                 process_name='LF', CommonDataObjct=None):
         if input_data_path:
             self.input_data_path = input_data_path
         else:
@@ -24,13 +25,17 @@ class LF_Input(InputData):
         if not CommonDataObjct:
             CommonDataObjct = CommonData()
 
+        if process_data_path is None:
+            process_data_path = Path(__file__).parent / "Data/LF_Input_MaterialDependent.csv"
+        self.add_process_data(process_data_path=process_data_path,
+                              index=CommonDataObjct.Index)
+
         self.gas_emission_factor = pd.read_csv(Path(__file__).parent / 'Data/LF_Gas_emission_factors.csv',
                                                converters={'Biosphere_key': ast.literal_eval})
         self.gas_emission_factor.fillna('', inplace=True)
 
-        self.lcht_coef = pd.read_csv(Path(__file__).parent / 'Data/LF_Leachate_Coeff.csv',
+        self.lcht_Qlty = pd.read_csv(Path(__file__).parent / 'Data/LF_Leachate_Quality.csv',
                                      converters={'Surface_water': ast.literal_eval, 'Ground_water': ast.literal_eval})
-        self.lcht_coef.fillna(0, inplace=True)
+        self.lcht_Qlty.fillna(0, inplace=True)
 
-        self.lcht_Alloc = pd.read_csv(Path(__file__).parent / 'Data/LF_Leachate_Allocation.csv',
-                                      index_col=0).loc[CommonDataObjct.Index]
+        self.GasColPlan = pd.read_csv(Path(__file__).parent / 'Data/LF_GasColPlan.csv', index_col=0)
